%
%
%
%SET ASPECT RATIO OF DRY HAIL
r_ice = 0.7;

%Constants for parameterization
m8 = 2.68e-4; %mass of 8 mm drop (kg)
rhow = 1000;  %density of liquid water (kg/m3)
rhoi = 917.0;  %density of ice
RH87 = 0.139;  %Prefactor for RH87 max wetness
C=1+RH87.*rhoi./rhow; %1.1275;   %See hail notes page 85-86
Dice = (0.1:0.1:40)./1000; % %equivalent spherical diameter (m) of dry hail
a=Dice.*r_ice.^(2.0/3.0);  % minor axis length of dry hail  (m) 
b = a./r_ice;  %major axis length of dry hail (m)

%ASSUMPTIONS FOR PARAMETERIZATION
del_a = zeros(1,numel(Dice)) + 0.05./1000;% The increment of the minor axis length (m) owing to liquid coating. 
                                           %Can be a percentage of a or a fixed amount like here;
  %see page 85-86 in hail notes for derivation
del_b = ((6.*m8./pi./rhow + C .* a.^3 ./ r_ice.^2) ./ (a+del_a)).^0.5 - a./r_ice;

r_part = (a+del_a)./(a./r_ice + del_b);  %Axis ratio of particle
%Dpart = ((a+del_a).*(b+del_b).^2).^(1.0./3.0);  %total particle diameter

%For those with unrealistically low aspect ratios
%
r_part_min = 0.56;  %minimum aspect ratio, that of largest drop

del_a2 = r_part_min.^(2.0./3.0) .* (6.*m8./pi./rhow + C.*a.^3./r_ice.^2).^(1.0./3.0)-a;
del_b2 = (a+del_a2)./r_part_min - b;

r_part2 = (a+del_a2)./(a./r_ice + del_b2); %Should equal 0.56

for x=1:numel(Dice)
    if r_part(x) < r_part_min;
        del_a(x) = del_a2(x);
        del_b(x) = del_b2(x);
        r_part(x) = r_part_min;
    else 
        del_a(x) = del_a(x);
        del_b(x) = del_b(x);
        r_part(x) = r_part(x);
    end
end

%%%Check
Dpart = ((a+del_a).*(b+del_b).^2).^(1.0./3.0);  %Diameter of entire particle
mass_liq = pi./6 .* rhow .* (Dpart.^3 - Dice.^3);  %mass of liquid should equal mwmax
mass_ice = pi./6 .* rhoi .* Dice.^3;  %mass of ice in kg
mwmax = m8+0.139.*mass_ice;

LWF = mass_liq ./ (mass_ice+mass_liq);


%%%%%%%%%%%%%%%%%%%%
%Ryzhkov parameters
%%%%%%%%%%%%%%%%%%%%%
r_R11 = zeros(1,numel(Dice)); rgh=r_R11;
rgh(1:100) = 1.0-0.02.*(Dice(1:100).*1000); rgh(101:end) = 0.8;  %Ryzhkov dry hail params
%aspect ratio varies as LWF
    poo = find(LWF < 0.2);  
    r_R11(poo)=rgh(poo) - 5.0 .* (rgh(poo) - 0.8).*LWF(poo);
    poo = find(LWF >= 0.2 & LWF < 0.8);
    r_R11(poo) = 0.88 - 0.4.*LWF(poo);
    Dmm=Dpart.*1000;
    rliq = 0.9951+0.02510.*Dmm - 0.03644 .* Dmm.^2 +0.005303 .* Dmm.^3 - 0.0002492 .* Dmm.^4;
    poo = find(LWF >= 0.8);
    r_R11(poo) = 2.8-4.0.*rliq(poo) + 5.0.*(rliq(poo)-0.56).*LWF(poo);
%orientation angle varies as LWF    
sigRain = 10;
sigHail = 60;
sigR11 = sigHail + LWF .* (sigRain - sigHail);

%Our parameterization: when a/b= max raindrop, keep at 10deg. Increase with
%LWF after
sigMK = sigHail + (r_ice-r_part)./max(r_ice-r_part) .* (sigRain - sigHail);

% SDL's attempt at canting widths - want ZDR hail signature to more
% accurately model the ZDR arc. Do this by ramping up the canting widths
% for hail sizes over 1 in = 2.5 cm = 25 mm

sigR11_MK = (sigR11 + sigMK)./2;    % average the two original distributions
sigHail_SDL = 60;       % maximum canting width (for larger, low LWF stones)

% Altering R11 and MK canting widths by constant or variable factors
sigSL_R11_constLWF = NaN(8,length(sigMK));
sigSL_R11_exponLWF = NaN(8,length(sigMK));
sigSL_MK_constFactor = NaN(8,length(sigMK));
sigSL_MK_exponFactor = NaN(8,length(sigMK));
expon = NaN(8,length(sigMK));
for e = 1:8
    expon(e,:) = linspace(0,1,length(sigMK)).^e + 1;
    
    sigSL_R11_constLWF(e,:) = sigHail + LWF.^(e) .* (sigRain - sigHail);
    sigSL_R11_exponLWF(e,:) = sigHail + LWF.^(expon(e,:)) .* (sigRain - sigHail);
    sigSL_MK_constFactor(e,:) = sigHail + ((r_ice-r_part)./max(r_ice-r_part)).^e...
                                .* (sigRain - sigHail);
    sigSL_MK_exponFactor(e,:) =  sigHail + ((r_ice-r_part)./max(r_ice-r_part)).^(expon(e,:))...
                                .* (sigRain - sigHail);                      
end

% Piece-wise jump to highest canting width at varying sizes, using R11, MK,
% and the average of the two as references

ind = 50:50:350;
sigSL_R11_piece = NaN(length(ind),length(sigMK));
sigSL_MK_piece = NaN(length(ind),length(sigMK));
sigSL_avg_piece = NaN(length(ind),length(sigMK));

for j = 1:length(ind)
    
    sigSL_R11_piece(j,1:ind(j)) = sigR11(1:ind(j));
    sigSL_R11_piece(j,ind(j)+1:end) = sigHail_SDL;
    
    sigSL_MK_piece(j,1:ind(j)) = sigMK(1:ind(j));
    sigSL_MK_piece(j,ind(j)+1:end) = sigHail_SDL;
    
    sigSL_avg_piece(j,1:ind(j)) = sigR11_MK(1:ind(j));
    sigSL_avg_piece(j,ind(j)+1:end) = sigHail_SDL;

end

% LWF piece-wise (jump to highest canting width once LWF < 0.5)
sigSL_R11_piece_LWF = sigR11;
sigSL_MK_piece_LWF = sigMK;
sigSL_avg_piece_LWF = sigR11_MK;

sigSL_R11_piece_LWF(LWF < 0.5) = sigHail_SDL;
sigSL_MK_piece_LWF(LWF < 0.5) = sigHail_SDL;
sigSL_avg_piece_LWF(LWF < 0.5) = sigHail_SDL;





